"""
    Title: HeadKuarter
    Title: rightclick.py
    Language: Python
    Date Created: 28-07-2022
    Date Modified: 12-08-2022
    Description: Add copy content functionality to context menu
        ###############################################################
        ##                     Main file                             ## 
        ###############################################################
 """
import os
import sys
import winreg as reg

def copyContent(): 

    # Get path of current working directory and python.exe
    cwd = os.getcwd()
    python_exe = sys.executable

    # optional hide python terminal in windows
    hidden_terminal = '\\'.join(python_exe.split('\\')[:-1])+"\\pythonw.exe"


    # Set the path of the context menu (right-click menu)
    key_path = r'txtfile\\shell\\CopyContent'

    # Create outer key
    key = reg.CreateKey(reg.HKEY_CLASSES_ROOT, key_path)
    reg.SetValue(key, '', reg.REG_SZ, '&Copy Content')  # Change 'Organise folder' to the function of your script

    # create inner key
    key1 = reg.CreateKey(key, r"command")
    reg.SetValue(key1, '', reg.REG_SZ, 'cmd /c clip < "%1"') 

def delet_key():
    cwd = os.getcwd()
    python_exe = sys.executable

    # optional hide python terminal in windows
    hidden_terminal = '\\'.join(python_exe.split('\\')[:-1])+"\\pythonw.exe"


    # Set the path of the context menu (right-click menu)
    key_path = r'txtfile\\shell\\CopyContent'
    key1_path = r'txtfile\\shell\\CopyContent\\command' # subkey

    # Create outer key
    key = reg.OpenKey(reg.HKEY_CLASSES_ROOT, key1_path)
    reg.DeleteKey(reg.HKEY_CLASSES_ROOT, key1_path)
    reg.DeleteKey(reg.HKEY_CLASSES_ROOT, key_path)
   

    


from setuptools import setup, find_packages
import app




setup(
    name='headkuterWIN',
    version=1.0,
    packages = ['Module','Module.veracrypt','Module.formosa','Module.gui','Module.keepass'],
    py_modules=['app','autoVera'],
    #package_data={'Module.formosa.themes':['Module\\formosa\\themes\\finances.json','Module\\formosa\\themes\\copy_left.json','Module\\formosa\\themes\\harry_potter.json','Module\\formosa\\themes\\medieval_fantasy.json','Module\\formosa\\themes\\sci-fi.json','Module\\formosa\\themes\\the_big_bang_theory.json','Module\\formosa\\themes\\tourism.json']},
    package_data={'Module.formosa.themes':['finances.json','copy_left.json','harry_potter.json','medieval_fantasy.json','sci-fi.json','the_big_bang_theory.json','tourism.json']},
    include_package_data=True,
    entry_points={
        'console_scripts': [
            'headkuter =app:headkurter'  #ponting to executeable function
        ]
    },
    install_requires=[
        'click==8.1.3',
        'colorama==0.4.4',
    ],
        #zip_safe = False
    )


"""
    Title: HeadKuarter
    Module Name: mountDrive
    Language: Python
    Date Created: 7-05-2022
    Date Modified: 7-05-2022
    Description:
        ###############################################################
        ##  mounting Veracrypt Encrypted container                   ## 
        ###############################################################
 """

import subprocess 
import logging
import json
import os

creat_at = "C:\\privateVdisk\\encryptvdisk1.vc"
drive = "X" # any letter
master_password = "MySuperSecurePassword1!"

def mount_drive(creat_at,drive,master_password):
    
    '''
    mount the encryted file to the drive
    '''
    success = False

    script = f"\"C:\Program Files\VeraCrypt\VeraCrypt.exe\" /volume \"{creat_at}\" /letter {drive} /password {master_password} /a /quit /silent"
    result = subprocess.run(script,stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
    #print(result)
    if result.returncode:
            return success
        
    success = True
    return success

def unmount(creat_at,drive):
    #unmount encrypted drive
    success = False
    script = f"\"C:\Program Files\VeraCrypt\VeraCrypt.exe\" /volume \"{creat_at}\" /dismount {drive}  /quit /silent"
    result = subprocess.run(script,stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
    #print(result)
    if result.returncode:
            return success
        
    success = True
    return success